# todo use interger_to_roman to convert the number to roman numerals
ROMANS = ['I', 'II', 'III', 'IV', 'V', 'VI', 'VII',
          'VIII', 'IX', 'X', 'XI', 'XII', 'XIII',
          'XIV', 'XV', 'XVI', 'XVII', 'XVIII', 'XIX',
          'XX', 'XXI', 'XXII', 'XXIII', 'XXIV', 'XXV',
          'XXVI', 'XXVII', 'XXVIII', ]

# TODO: these might not be accurate
LENT_MASSES = ('Sicut oculi', 'Domine refugium', 'Reminíscere', 'Confessio',
               'De necessitatibus', 'Intret oratio', 'Redime me', 'Tibi dixit',
               'Ne derelinquas me', 'Deus, in adjutorium', 'Ego autem',
               'Lex Domini', 'In Deo laudabo', 'Ego clamavi', 'Ego autem',
               'Salus populi', 'Fac mecum', 'Verba mea', 'Deus, in nomine',
               'Exaudi, Deus', 'Cum sanctificatus', 'Lætetur cor', 'Meditatio',
               'Sitientes', 'Miserere mihi', 'Expecta Dominum',
               'Liberator meus', 'Omnia, quæ fecisti', 'Miserere mihi',
               'Miserere mihi',)

# beginning with the fourth Sunday after Pentecost
# TODO: double check the last ones...
PENTECOST_MASSES = ('Dominus illuminatio', 'Exaudi, Domine',
                    'Dominus fortitudo', 'Omnes gentes', 'Suscepimus',
                    'Ecce Deus', 'Cum clamarem', 'Deus in loco',
                    'Deus in adjutorium', 'Respice Domine', 'Protector noster',
                    'Inclina Domine', 'Miserere mihi', 'Justus es', 'Da pacem',
                    'Salus populi', 'Omnia', 'In voluntate tua',
                    'Si iniquitates', 'Dicit Dominus', 'Dicit Dominus',)

EPIPHANY_MASSES = ('', )



from ordo_tools.helpers import day


class Country:
    """
    Proper days of a country, which are called by the diocese.
    """

    def __init__(self, year):
        self.name = "Australiae"
        self.year = year
        self.data = {
            day(year=self.year, month=3, day=17): {
                # This feast has a Common Octave if it is transferred outside
                # of Lent, which happens if Easter is between March 22 and
                # March 24.
                "feast": "S. Patritii E.C. Patroni Hiberniae",
                "rank": [5, "d I cl"],  # check the ranking
                # "rank": [0, 4, 1, 1, "DICL"],
                "nobility": (False,),
                "com": [],
                "office_type": False,
                "color": "white",
                "mass": {
                    "int": "Statuit",
                    "glo": True,
                    # exception where St. Patrick Principal Patron of
                    # Diocese, Titular of Cathedral, or where Indult granted
                    "cre": False,
                    "pre": "Communis"
                },
                "matins": {
                    "L1": "",
                    "L2": "",
                    "L3": "",
                    "L4": "",
                    "L5": "",
                    "L6": "",
                    "L7": "",
                    "L8": "",
                    "L9": "",
                },
                "lauds": {},
                "prime": {},
                "little_hours": {},
                # common antiphons
                "vespers": {
                    "proper": False,
                    "admag": ("Sacerdos et Pontifex", "Amavit eum Dominus"),
                    "propers": {
                        "hymn": "",
                        "verse": ""
                    },
                    "oration": "Deus, qui ad praedicandam"
                },
                "compline": {},
                "fasting": False,
            }
        }


# NOTE:
# 'Omnia de Communi Conf. Pont. praeter sequentia.
# Oratio ut in Brevario.
# In I Nocturno Lectiones Fidelis sermo, de eodem Communi I loco.
# In II et III Nocturno Lectiones ut in Breviario.
# IX Lectio de Homilia Feriae, et fit ejus Com. ad Laudes.
# In II Vesperis Com. sequentis et Feriae.'



import logging


# logging.basicConfig(filename='app.log', filemode='w',
#                     format='%(name)s - %(levelname)s - %(module)s - %(lineno)d - %(message)s', level=logging.INFO)


# Create a custom logger
logger = logging.getLogger(__name__)

# Create handlers
c_handler = logging.StreamHandler()
f_handler = logging.FileHandler('app.log')
c_handler.setLevel(logging.WARNING)
f_handler.setLevel(logging.INFO)

# Create formatters and add it to handlers
c_format = logging.Formatter(
    '%(asctime)s - %(name)s - %(levelname)s - %(module)s - %(lineno)d - %(message)s')
f_format = logging.Formatter(
    '%(asctime)s - %(name)s - %(levelname)s - %(module)s - %(lineno)d - %(message)s')
c_handler.setFormatter(c_format)
f_handler.setFormatter(f_format)

# Add handlers to the logger
logger.addHandler(c_handler)
logger.addHandler(f_handler)
